<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fa_IR">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>پرش به پی.دی.اف</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>بدون پیشنهاد</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>نادیده‌گرفتن کلمه</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>ناتوان در حذف</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>بعضی از پرونده‌های کمکی نمی‌توانند حذف شوند. شاید اجازهٔ این کار را ندارید.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>تأیید حذف پرونده</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>پرونده‌های کمکی که حذف می‌شوند:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>انتخاب همه</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>انتخاب هیچ‌کدام</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>جابجایی</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>پیدا کن</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>پیدا کن:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;پوشاندن</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>پیدا کردن &amp;عقب‌گرد</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>جستجو در &amp;انتخاب</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>پیدا کردن &amp;تمام موارد</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>جستجوی همهٔ &amp;پرونده‌های باز</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;جساس به بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>ه&amp;مهٔ کلمات</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;عبارت منظم</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>فاقد رشتهٔ جستجوی اخیر</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(نامعتبر)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>پوشاندن شدید</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>خط‌ها را بپوشان به:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>اندازهٔ پنجرهٔ جاری</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>طول خط:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>بازپوشاندن پاراگراف‌ها</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>گشودن اخیر</translation>
    </message>
    <message>
        <source>PDF file &quot;%1&quot; is locked; this is not currently supported.</source>
        <translation>پروندهٔ پی‌دی‌اف &quot;%1&quot; قفل است؛ فعلاً حمایت نمی‌شود.</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>ناموفق در بازگذاری پروندهٔ &quot;%1&quot;؛ شاید مستند پی‌دی‌اف معتبری نیست.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>اطلاعات همگام تک موجود نیست</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>همگام تک: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>صفحهٔ %1 از %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>untitled.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ویرایش</translation>
    </message>
    <message>
        <source>View</source>
        <translation>مشاهده</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>نمایش</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>میلهٔ ابزار</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>دربارهٔ تک‌ورکس...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>صفحهٔ اول</translation>
    </message>
    <message>
        <source>Home</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>خانه</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>صفحهٔ قبل</translation>
    </message>
    <message>
        <source>PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>صفحهٔ بالا</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>صفحهٔ بعد</translation>
    </message>
    <message>
        <source>PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>صفحهٔ پایین</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>صفحهٔ آخر</translation>
    </message>
    <message>
        <source>End</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>پایان</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>برو به صفحهٔ ...</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>یزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>کوچک‌نمایی</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl--</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>پرکردن پنجره</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>اندازهٔ واقعی</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>پرکردن عرض</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>پس‌گرد</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>پیش‌گرد</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>بریدن</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخه‌برداری</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چسباندن</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاک‌کردن</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ترجیحات...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>نصف صفحه</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>برو به منبع</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>جدید از الگو...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>تمام‌صفحه</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>لغزاندن</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>انتخاب متن</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>انتخاب تصویر</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به صفحهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>ایمیل به لیست ایمیل</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>پهلو به پهلو</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>قراردادن در چپ</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>قراردادن در راست</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>خروج از تک‌ورکس</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>پیدا کن...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>دوباره پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سند</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>سندسازی تک‌ورکس</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>بازخوانی لیست سندها</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>مدیریت سندها</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>نمایش پوشهٔ سندها</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>دربارهٔ سند...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>چاپ پی‌دی‌اف...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>لغو حروف‌چینی</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>به دلیل مشکلات تکنیکی، متأسفانه این ویراست از %1 قادر به چاپ پی‌دی‌اف نیست.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>برای چاپ، آیا می‌خواهید پرونده را در نمایشگر پیش‌فرض باز کنید؟</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation>(به یاد داشته باشید که آن را برای عدم مشکلات دسترسی ببندید)</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>پیدا کن</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>فاقد رشتهٔ جستجوی اخیر</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>در پی‌دی‌اف پیدا کن</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>پیدا کن:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;پوشاندن</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>پیدا کن &amp;عقب‌گرد</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>پیدا کن &amp;همهٔ موارد</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;حساس به بزرگ و کوچکی حروف</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;همگام به منبع</translation>
    </message>
</context>
<context>
    <name>PDFFontsDock</name>
    <message>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>نوع</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation>زیرمجموعه</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[هیچ‌کدام]</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>بله</translation>
    </message>
    <message>
        <source>no</source>
        <translation>خیر</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[نشانده]</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>قلم‌ها</translation>
    </message>
</context>
<context>
    <name>PDFInfoDock</name>
    <message>
        <source>PDF Info</source>
        <translation>اطلاعات پی‌دی‌اف</translation>
    </message>
</context>
<context>
    <name>PDFOutlineDock</name>
    <message>
        <source>No TOC</source>
        <translation>فاقد فهرست</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>فهرست</translation>
    </message>
</context>
<context>
    <name>PDFWidget</name>
    <message>
        <source>Zoom In</source>
        <translation>بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>کوچک‌نمایی</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>اندازهٔ واقعی</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>پرکردن عرض</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>پرکردن پنجره</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>جهش به کد</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>برو به صفحهٔ</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>شمارهٔ صفحه:</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>انتخاب پوشه</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>ابزار جدید</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>پیش‌فرض سیستم [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ‌کدام</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>ترجیحات تک‌ورکس</translation>
    </message>
    <message>
        <source>General</source>
        <translation>عمومی</translation>
    </message>
    <message>
        <source>Toolbar buttons</source>
        <translation>کلیدهای میلهٔ ابزار</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>آیکون‌ها کوچک</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>آیکون‌ها متوسط</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>آیکون‌ها بزرگ</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>نمایش متن همراه با آیکون‌ها</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>به‌محض اجرا، نمایش بده</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>مستند خالی جدید</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>الگوی گفتگوی انتخاب</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>گفتگوی گشودن پرونده</translation>
    </message>
    <message>
        <source>Interface locale:</source>
        <translation>شمایل محلی:</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>ویرایشگر</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>پیش‌فرض ویرایشگر</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>پوینت</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>عرض اتیکت:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>شمارهٔ خط‌ها</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>بسته‌بندی خط‌ها</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>رنگ‌آمیزی  نحوی:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>حالت تورفتگی خودکار:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>زبان غلط‌گیر:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>رمزینه:</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>انتخاب‌های عمومی ویرایشگر</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>پررنگ کردن خط جاری</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>پیش‌نمایش</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>مقیاس پیش‌فرض</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>اندازهٔ واقعی</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>پرکردن عرض</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>پرکردن پنجره</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>مقیاس ثابت:</translation>
    </message>
    <message>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>عدسی بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>کوچک</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>متوسط</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>بزرگ</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>بزرگ‌نمای گرد</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>دقت صفحه:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation>دی‌پی‌آی</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>مسیر تک و برنامه‌های مرتبط</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>ابزارهای پردازش</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>ویرایش...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>پیش‌فرض:</translation>
    </message>
    <message>
        <source>Auto-hide output panel unless errors occur</source>
        <translation>پنهان‌کردن خودکار خروجی مگر خطا وجود داشته باشد</translation>
    </message>
    <message>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>حالت نقل قول هوشمند:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سندها</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>امنیت</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>اجازهٔ خواندن تمام پرونده‌ها به سندها (سندها و پرونده‌های عادی همیشه قابل خواندن هستند)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>اجازهٔ نوشتن فایل‌ها به سندها</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>اجازهٔ اجرای فرمان‌های سیستم به سندها</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>فعال‌سازی افزونهٔ زبان‌های سند (ممکن است محدودیت‌های دیگری بر رفتار سندها اعمال کند)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>اشکال زدایی</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>فعال‌سازی اشکال‌زایی QtScript</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>QT_LAYOUT_DIRECTION</source>
        <translation type="obsolete">RTL</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>مستندات تک (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>مستندات لاتک (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>پایگاه بایب‌تک (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>پرونده‌های سبکی (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>پرونده‌های طبقه (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>ماکروهای تشریح شده (*.dtx)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</source>
        <translation>پرونده‌های کمکی (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>پرونده‌های متنی (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>مستندات پی‌دی‌اف (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>همهٔ پرونده‌ها</translation>
    </message>
    <message>
        <source>TeXworks %1r%2 (%3)
</source>
        <translation type="obsolete">تک‌ورکس %1 ب %2 (%3)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>جایگزینی</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>جایگزینی همه</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>لغو</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>فاقد رشتهٔ جستجوی اخیر</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>فاقد رشتهٔ جایگزینی اخیر</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(نامعتبر)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>جایگزینی:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>با:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;پوشاندن</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>پیدا کن &amp;عقب‌گرد</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>جایگزینی با &amp;انتخاب</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>جایگزینی در همه &amp;پرونده‌های باز</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;حساس به بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>ه&amp;مهٔ کلمات</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;عبارت منظم</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>مدیریت سندها</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>سند مستقل</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>سند لنگری</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>نام:</translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>متن:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>توضیح:</translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>نویسنده:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>ویراست:</translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>میان‌بر:</translation>
    </message>
    <message>
        <source>File: </source>
        <translation>پرونده:</translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>زبان:</translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>لنگر:</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>End</source>
        <translation>پایان</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>متن</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>نتایج جستجو</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>نتایج جستجو - %1 (%2 پیدا شد)</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>جدید از الگو...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ترجیحات...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>گشودن اخیر</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به صفحهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>ایمیل به لیست ایمیل</translation>
    </message>
    <message>
        <source>About </source>
        <translation>درباره</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;‫%1 محیطی ساده برای نگارش، حروف‌چینی، و نمایش مستندات تک است. ‬&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (r.%2)</source>
        <translation type="obsolete">&lt;br&gt;‫نسخهٔ %1 (ب.%2‏)‬</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
        <translation>&lt;p&gt; انتشار‌یافته تحت &lt;a href=&quot;http://www.gnu.org/licences/gpl-2.0.html&quot;&gt; اجازه‌نامهٔ عمومی گنو&lt;/a&gt;, نسخهٔ ۲.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; application framework by Qt Software, a division of Nokia Corporation.</source>
        <translation type="obsolete">&lt;p&gt;چهارچوب کاربری &lt;a href=&quot;http://trolltech.com/product/&quot;&gt;QT4&lt;/a&gt; توسط شرکت  QT , وابسته به شرکت نوکیا.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;کتابخانهٔ مترجم پی‌دی‌اف &lt;a href=&quot;http.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; توسط Kristian H&amp;#xF8;gsberg, Albert Astals Cid و دیگران.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.sourceforge.net/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;غلط‌یاب&lt;a href=&quot;http://hunspell.sourceforge.net/&quot;&gt;Hunspell&lt;/a&gt; توسط L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;مفاهیم و منابع از &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TexShop&lt;/a&gt; توسط Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;فناوری &lt;a href=&quot;http://itemac.sourceforge.net/SyncTex.html&quot;&gt;SyncTex&lt;/a&gt; توسط J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;بعضی از آیکون‌های استفاده شده از پروژهٔ &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt; هستند.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt; ارائهٔ ترجمهٔ ‫%1 از %2‏.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>فارسی</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>مهدی امیدعلی/mehdioa@gmail.com</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>دربارهٔ %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>ناتوان در دسترسی به &quot;%1&quot;؛ شاید مرورگر و نرم‌افزار کاربردی ایمیل شما به‌درستی تنظیم نشده است؟</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>ناتوان در ساختن پنجره</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>چیزی به‌شدت غلط است، %1 نتوانست پنجرهٔ مستند را بسازد. نرم‌افزار کاربردی خارج می‌شود.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>گشودن پرونده</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>پوشهٔ باینری پیش‌فرض یافته نشد</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.</source>
        <translation>هیچ‌کدام از پوشه‌های معرفی‌شده برای برنامه‌های مرتبط با تک پیدا نمی‌شوند. &lt;p&gt;&lt;small&gt;برای اجرای هر پردازشی، باید پوشه‌های باینری توزیع تک خود را از گزینهٔ حروف‌چینی از گفتگوی ترجیحات تنظیم کنید.</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>پروندهٔ کمکی یافت نشد.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
        <translation>&lt;br&gt;ویراست %1 ب.%2 (%3)</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;چهارچوب نرم‌افزاری Qt &lt;/a&gt; v%1 توسط  Qt Software, a division of Nokia Corporation.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>ذخیرهٔ پرونده</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>درخواست اجازه</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>سند &quot;%1&quot;در حال گشودن پروندهٔ &quot;%2&quot; بدون اجازهٔ کافی است. آیا می‌خواهید پرونده را باز کنید؟</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>خطای داخلی</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>ناتوان در اجرای فرمان سیستم: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>خطا در اجرای فرمان سیستم:%1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>اجرای فرمان سیستم ناممکن است ( ترجیحات را ببینید)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; نمی‌تواند باز شود.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>خواندن تمامی پرونده‌ها ناممکن شده است (ترجیحات را ببینید)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>پروندهٔ &quot;%1&quot; را برای خواندن نمی‌تون گشود</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>سند &quot;%1&quot;:%2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>نتیجه سند</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>خطای نامشخص</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>سند می‌تواند برای افزودن فرمان جدید به %1 ، یا گسترش و یا بهسازی آن مورد استفاده قرار گیرد.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>برای اطلاعات بیشتر در مورد ایجاد و استفاده از سندها به %1 مراجعه شود &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>زبان‌های سند در دسترس در این ویراست از %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>دربارهٔ سند</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>خطا: کد شکست %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>خطا: کد خروج %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>اتیکت‌ها</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>چوب‌خط‌ها</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>کلیت</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>بدون اتیکت</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>مستند جدید</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>گشودن اخیر</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ‌کدام</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>گشودن پرونده</translation>
    </message>
    <message>
        <source>Cannot close window while tool is running</source>
        <translation type="obsolete">وقتی ابزار در حال اجراست پرونده نمی‌تواند بسته شود</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>ذخیرهٔ پرونده</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>مستند &quot;%1&quot; اصلاح شده است.
آیا می‌خواهید تغییرات را ذخیره کنید؟</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>آیا می‌خواهید تمام تغییرات مستند &quot;%1&quot; را دور بیندازید، و به آخرین نسخهٔ ذخیره‌شده برگردید؟</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>برگرداندن</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">ناتوان در خواندن پروندهٔ &quot;%1&quot;:
%2.</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>رمزینهٔ ناشناخته</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>رمزینهٔ متنی %1 استفاده شده در %2 حمایت نمی‌شود.

به‌جای آن از %3 استفاده می‌شود، که ممکن است متن درست نمایش داده نشود.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded (%2)</source>
        <translation type="obsolete">پروندهٔ &quot;%1&quot; بارگذاری شد (%2)</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>پرونده روی دیسک تغییر کرد</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 توسط برنامهٔ دیگری اصلاح شده است.

آیا می‌خواهید تغییرات شما دور انداخته شود، و پرونده از دیسک فراخوانی شود؟</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 توسط برنامهٔ دیگری اصلاح شده است.

آیا می‌خواهید پرونده را در دیسک دوباره بنویسید؟</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>مستند &quot;%1&quot; ذخیره نشده است</translation>
    </message>
    <message>
        <source>The text encoding %1 requested for %2 is not supported.

It will be saved as %3 instead, which may result in incorrect text.</source>
        <translation type="obsolete">رمزینهٔ متنی %1 استفاده شده در %2 حمایت نمی‌شود.

به‌جای آن از %3 استفاده می‌شود، که ممکن است متن درست نمایش داده نشود.</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>متن قابل تبدیل نیست</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>این مستند شامل کاراکترهایی است که در رمزینهٔ %1 قابل نمایش نیست.

اگر ادامه دهید، این کاراکترها با مقادیر رمزینهٔ پیش‌فرض جایگزین می‌شوند. به‌جای این کار ممکن است بخواهید از رمزینهٔ دیگری مانند UTF-8 استفاده کنید تا اطلاعات از دست نروند.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">ناتوان از نوشتن پروندهٔ &quot;%1&quot;
%2.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved (%2)</source>
        <translation type="obsolete">پروندهٔ &quot;%1&quot; ذخیره شد (%2)</translation>
    </message>
    <message>
        <source>default encoding</source>
        <translation type="obsolete">رمزینهٔ پیش‌فرض</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>untitled-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>خط %1 از %2؛ ستون %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>برو به خط</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>شمارهٔ خط‌ها:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>عبارت منظم نامعتبر</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>پیدا نشد</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>%n% مورد پیدا شد</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n مورد</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n مستند</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>جایگزینی %1 در %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>جایگزینی %n مورد</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>مستند ذخیره نشده قابل اجرا نیست</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>مستند ریشهٔ %1 قابل خواندن نیست</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 به‌درستی تنظیم نشده است</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>ناتوان در اجرای %1</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>برنامهٔ %1 پیدا نشد.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>جستجو در پوشه‌های:</translation>
    </message>
    <message>
        <source>Check configuration of the %1 tool and path settings in the Preferences dialog.</source>
        <translation>تنظیمات ابزار و مسیر %1 را در گفتگوی ترجیحات بررسی کنید.</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>پردازش توسط کابر متوقف شد</translation>
    </message>
    <message>
        <source>Hide Output Panel</source>
        <translation>پنل خروجی را پنهان کن</translation>
    </message>
    <message>
        <source>Show Output Panel</source>
        <translation>پنل خروجی را ظاهر کن</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>تنظیم موتور به %1</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>موتور &quot;%1&quot; تعریف نشده است</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>پرونده‌ای پیدا نشد</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>هیچ پروندهٔ کمکی مربوط با این مستند در حال حاضر پیدا نشد.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>untitled.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ویرایش</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>بررسی املا</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>تغییر بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>حروف‌چین</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>نمایش</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>شمایل</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>حالت خودکار تورفتگی</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>رنگ‌آمیزی  نحوی</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>نقل هوشمند</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>میلهٔ ابزار حروف‌چینی</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>میلهٔ ابزار ویرایش</translation>
    </message>
    <message>
        <source>New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>ذخیره به‌عنوان...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>برگرداندن به ذخیره شده</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>پس‌گرد</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>پیش‌گرد</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>بریدن</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخه‌برداری</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چسباندن</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاک‌کردن</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>پیدا کن...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>دوباره پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>جایگزینی...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>ذخیره در پیدا شده</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>ذخیره در جایگزین شده</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>برو به خط...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>انتخاب شده را پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>انتخاب همه</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>قلم...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>تورفتگی</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>بدون تورفتگی</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>توضیح</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>خارج از توضیح</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>بسته‌بندی خط‌ها</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>دربارهٔ تک‌ورکس...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>نصف صفحه</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ترجیحات...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>برو به پیش‌نمایش</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>جدید از الگو...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>نمایش انتخاب</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>همهٔ حروف بزرگ</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>همهٔ حروف کوچک</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>موازنهٔ حائل‌ها</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به صفحهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>ایمیل به لیست ایمیل</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>پهلو به پهلو</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>قراردادن در چپ</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>قراردادن در راست</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>جایگزینی دوباره</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>حذف پرونده‌های کمکی...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>خروج از تک‌ورکس</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Qtrl+Q</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>جابجایی بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>پوشاندن شدید...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>شمارهٔ خط‌ها</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>پیشانه خروجی</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سندها</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>سندسازی تک‌ورکس</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>نمایش پوشهٔ سندها</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>بازخوانی لیست سندها</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>مدیریت سندها</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>دنبالگر کانونی خودکار</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>دربارهٔ سند...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>اعمال بر انتخاب شده</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>ذخیره همه</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>ناتوان در خواندن پروندهٔ &quot;%1&quot;:
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>پروندهٔ &quot;%1&quot; بارگذاری شد</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 توسط برنامهٔ دیگری دائماً تغییر می‌یابد.

بعد از پایان پردازش، لطفاً از «پرونده &gt; تغییر به ذخیره شده»  به صورت دستی استفاده کنید.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>ناتوان از نوشتن پروندهٔ &quot;%1&quot;
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>خطا در نوشتن پرونده</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>خطایی در هنگام نوشتن پرونده رخ داد. ممکن است بخواهید یک نسخه از پرونده را در مکانی دیگر ذخیره کنید.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>پروندهٔ &quot;%1&quot; ذخیره شد</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>لغو حروف‌چینی</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>پیش‌فرض</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>پروندهٔ جدید با استفاده از الگو</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>الگوی پروندهٔ جدید را انتخاب کنید:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>گزینهٔ جدید</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>انتخاب پروندهٔ برنامه</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>برنامهٔ نامعتبر</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>پروندهٔ &apos;%1&apos; اجرایی نیست!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>تنظیم ابزار</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>نام:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>برنامه:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>گزینه‌ها:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>مشاهدهٔ پی‌دی‌اف پس از اجرا</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>ورق زدن (جستجو)...</translation>
    </message>
</context>
</TS>
